******************************************************************************************************************************************
****************ANALYSIS FOR THE PAPER "MIND THE FRAMING WHEN STUDYING SOCIAL PREFERENCES IN THE DOMAIN OF LOSSES"************************
******************************************************************************************************************************************

***Read Me: This .do file does not contain the analysis for Section 3.3, Tables A.5, A.6, Appendix B.2. 
***The missing analysis will be presented in a separate .do file

clear

use "data_loss_Final.dta" //choose your path

***Participant Payoffs

gen payoff_recipient=.
replace payoff_recipient=A_decision if Treatment==0 & Player==2 //Player B's payoff in the control group
replace payoff_recipient=A_decision if Treatment==11 & Player==2 //Player B's payoff Loss manipulation 1
replace payoff_recipient=A_decision if Treatment==12 & Player==2 //Player B's Loss 1 Loss Manipulation 1 (No LOSS)

*3-A_decision=the amount of loss A sends to be. 3-(3-A_decision) is the payoff of the recipient. 

replace payoff_recipient=3-(3-A_decision) if Treatment==21 & Player==2 //Player B's payoff Loss manipulation 2
replace payoff_recipient=3 if Treatment==20 & Player==2 //Player B's payoff Loss manipulation 2 (NO LOSS)


***generating a new treatment variable

gen Treatment_New=.

replace Treatment_New=0 if Treatment==0 & RealEffort==0 & Session<=3 //Control, No Real Effort
replace Treatment_New=1 if Treatment==11 & RealEffort==0 & Session<=3 //Loss 1, No Real Effort
replace Treatment_New=2 if Treatment==21 & RealEffort==0 & Session<=3 //Loss 2, No Real Effort

replace Treatment_New=3 if Treatment==0 & RealEffort==1 & Session<=3 //Control, Real Effort
replace Treatment_New=4 if Treatment==11 & RealEffort==1 & Session<=3 //Loss 1, Real Effort
replace Treatment_New=5 if Treatment==21 & RealEffort==1 & Session<=3 //Loss 2, Real Effort

replace Treatment_New=6 if Treatment==0 & RealEffort==1 & Session>3 //Control, Real Effort S3
replace Treatment_New=7 if Treatment==11 & RealEffort==1 & Session>3 //Loss 1, Real Effort S3
replace Treatment_New=8 if Treatment==21 & RealEffort==1 & Session>3 //Loss 2, Real Effort S3



label define treatment 0 "Control S1" 1 "LM1 S1" 2 "LM2 S1" 3 "Control S2" 4 "LM1 S2"  5 "LM2 S2" 6 "Control S3" 7 "LM1 S3"  8 "LM2 S3"
label values Treatment_New treatment

*************
***Table 2***
*************

**Dictators & Recipients

**Number of dictators

ta Treatment if Player==1 & Study==1
ta Treatment if Player==1 & Study==2
ta Treatment if Player==1 & Study==3

**Number of recipients

ta Treatment if Player==2 & Study==1
ta Treatment if Player==2 & Study==2
ta Treatment if Player==2 & Study==3


***Female column

bysort Study Treatment Player: su female if Player==1
bysort Study Treatment Player: su female if Player==2

*** Age column of Table 1

bysort Study Treatment Player: su age if Player==1
bysort Study Treatment Player: su age if Player==2

su female
su age


**NOTE: Since there are missing values for age and gender, the number of observations for these variables does not coincide with the overall number of observations in the Observation column of Table 1.


**************
***FIGURE 2***
**************

***Panel A Selfish

gen selfish=0 if payoff_recipient!=.
replace selfish=1 if Treatment==0 & payoff_recipient==0 | Treatment==11 & payoff_recipient==0 | Treatment==21 & payoff_recipient==0 

cibar selfish if payoff_recipient!=. & Treatment_New==0 | payoff_recipient!=. & Treatment_New==1 | ///
payoff_recipient!=.& Treatment_New==2 | payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==4 | ///
payoff_recipient!=. & Treatment_New==5 | payoff_recipient!=. & Treatment_New==6 | payoff_recipient!=. & Treatment_New==7 ///
| payoff_recipient!=. & Treatment_New==8, over(Treatment_New)  ///
bargap(10) barlabel(on) barcolor(gs9 lavender ltkhaki ltblue maroon pink dkgreen mint teal) graphopts(ylabel(0(0.2)1, angle(0)) legend(size(small)) graphregion(color(white)) ///
ytitle("Fraction of selfish dictators", size(small)) title("Panel A: Selfish dictators", size(small)) xline(3.85 7.14) name(Fig_1a, replace) legend(rows(3)  position(6)) text(1 1.65 "Study 1"  ///
,place(e)) text(1 4.85 "Study 2",place(e)) text(1 7.85 "Study 3",place(e)))
 
graph save "figures/selfish_dictators.gph", replace
graph export "figures/selfish_dictators.png", replace


***Panel B Somewhat Altruistic

gen smw_altruist=0 if payoff_recipient!=. 
replace smw_altruist=1 if Treatment==0 & payoff_recipient>0 & payoff_recipient<1.5 | Treatment==11 & payoff_recipient>0 & payoff_recipient<1.5 | ///
Treatment==21 & payoff_recipient>0 & payoff_recipient<1.5

cibar smw_altruist if payoff_recipient!=. & Treatment_New==0 | payoff_recipient!=. & Treatment_New==1 | ///
payoff_recipient!=. & Treatment_New==2 | payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==4 ///
| payoff_recipient!=. & Treatment_New==5 | payoff_recipient!=. & Treatment_New==6 | payoff_recipient!=. & Treatment_New==7 ///
| payoff_recipient!=. & Treatment_New==8 , over(Treatment_New) ///
bargap(10) barlabel(on) barcolor(gs9 lavender ltkhaki ltblue maroon pink dkgreen mint teal) graphopts(ylabel(0(0.2)1, angle(0)) legend(size(small)) graphregion(color(white)) ///
ytitle("Fraction of somwehat altruistic dictators", size(small)) title("Panel B: Somewhat altruistic dictators", size(small)) xline(3.85 7.14) name(Fig_1b, replace) legend(rows(3)  position(6)) text(1 1.65 "Study 1" ///
,place(e)) text(1 4.85 "Study 2",place(e)) text(1 7.85 "Study 3",place(e)))
graph save "figures/smw_altruist_dictators.gph", replace
graph export "figures/smw_altruist_dictators.png", replace


**Panel C Highly Altruistic

gen fair_and_above=0 if payoff_recipient!=.
replace fair=1 if Treatment==0 & payoff_recipient>=1.5 & payoff_recipient!=. | Treatment==11 & payoff_recipient>=1.5 & payoff_recipient!=. | Treatment==21 & payoff_recipient>=1.5 & payoff_recipient!=.

cibar fair_and_above if payoff_recipient!=. & Treatment_New==0 | payoff_recipient!=. & Treatment_New==1 | ///
payoff_recipient!=. & Treatment_New==2 | payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==4 ///
| payoff_recipient!=. & Treatment_New==5 | payoff_recipient!=. & Treatment_New==6 | payoff_recipient!=. & Treatment_New==7 ///
| payoff_recipient!=. & Treatment_New==8 , over(Treatment_New) ///
bargap(10) barlabel(on) barcolor(gs9 lavender ltkhaki ltblue maroon pink dkgreen mint teal) graphopts(ylabel(0(0.2)1, angle(0)) legend(size(small)) graphregion(color(white)) ///
ytitle("Fraction of highly altruistic dictators", size(small)) title("Panel C: Highly altruistic dictators", size(small)) xline(3.85 7.14) name(Fig_1c, replace) legend(rows(3)  position(6)) text(1 1.65 "Study 1" ///
,place(e)) text(1 4.85 "Study 2",place(e)) text(1 7.85 "Study 3",place(e)))

graph save "figures/hghly_altruist_dictators.gph", replace
graph export "figures/hghly_altruist_dictators.png", replace


grc1leg Fig_1a Fig_1b Fig_1c

graph export "figures/combined.png", replace


**************
***Figure 3***
**************

cibar payoff_recipient if payoff_recipient!=. & Treatment_New==0 | payoff_recipient!=. & Treatment_New==1 | ///
payoff_recipient!=. & Treatment_New==2 | payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==4 | ///
payoff_recipient!=. & Treatment_New==5 | payoff_recipient!=. & Treatment_New==6 | payoff_recipient!=. & Treatment_New==7 ///
| payoff_recipient!=. & Treatment_New==8, over(Treatment_New) ///
bargap(10) barlabel(on) barcolor(gs9 lavender ltkhaki ltblue maroon pink dkgreen mint teal) graphopts(ylabel(0(0.5)3, angle(0)) legend(size(small) position(6) rows(3)) graphregion(color(white)) ///
ytitle("Payoff") xline(3.85 7.14) text(3 1.65 "Study 1" ///
,place(e)) text(3 4.85 "Study 2",place(e)) text(3 7.85 "Study 3",place(e)))

graph save "figures/payoff1.gph", replace
graph export "figures/payoff1.png", replace

**************
***Figure 6***
**************

gen payoff_based_A_beliefs=.
replace payoff_based_A_beliefs=A_beliefs if Treatment==0 & Player==2 
replace payoff_based_A_beliefs=A_beliefs if Treatment==11 & Player==2 
replace payoff_based_A_beliefs=A_beliefs if Treatment==12 & Player==2 
replace payoff_based_A_beliefs=3-A_beliefs if Treatment==21 & Player==2
replace payoff_based_A_beliefs=3 if Treatment==20 & Player==2


cibar payoff_based_A_beliefs if payoff_recipient!=. & Treatment_New==0 | payoff_recipient!=. & Treatment_New==1 | ///
payoff_recipient!=. & Treatment_New==2 | payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==4 | ///
payoff_recipient!=. & Treatment_New==5 | payoff_recipient!=. & Treatment_New==6 | payoff_recipient!=. & Treatment_New==7 | ///
payoff_recipient!=. & Treatment_New==8, over(Treatment_New) ///
bargap(10) barlabel(on) barcolor(gs9 lavender ltkhaki ltblue maroon pink dkgreen mint teal) graphopts(ylabel(0(0.5)3, angle(0)) legend(rows(3) size(small) position(6)) graphregion(color(white)) ///
ytitle("Recipients' payoffs based on dictators' beliefs", size(small)) xline(3.85 7.14) text(3 1.85 "Study 1" ///
,place(e)) text(3 4.85 "Study 2",place(e)) text(3 7.85 "Study 3",place(e)))

graph save "figures/payoff_beliefs.gph", replace
graph export "figures/payoff_beliefs.png", replace


*********************************************************
***Non-parametric tests comparing beliefs in Section 4***
*********************************************************

ranksum payoff_based_A_beliefs if payoff_recipient!=. & Treatment_New==0 | payoff_recipient!=. & Treatment_New==1, by(Treatment) //Control S1 vs LM1 S1
ranksum payoff_based_A_beliefs if payoff_recipient!=. & Treatment_New==0 | payoff_recipient!=. & Treatment_New==2, by(Treatment) //Control S1 vs LM2 S1
ranksum payoff_based_A_beliefs if payoff_recipient!=. & Treatment_New==1 | payoff_recipient!=. & Treatment_New==2, by(Treatment) //LM1 S1 vs LM2 S1

ranksum payoff_based_A_beliefs if payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==4, by(Treatment) //Control S2 vs LM1 S2
ranksum payoff_based_A_beliefs if payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==5, by(Treatment) //Control S2 vs LM2 S2
ranksum payoff_based_A_beliefs if payoff_recipient!=. & Treatment_New==4 | payoff_recipient!=. & Treatment_New==5, by(Treatment) //LM1 S2 vs LM2 S2


ranksum payoff_based_A_beliefs if payoff_recipient!=. & Treatment_New==6 | payoff_recipient!=. & Treatment_New==7, by(Treatment) //Control S2 vs LM1 S2
ranksum payoff_based_A_beliefs if payoff_recipient!=. & Treatment_New==6 | payoff_recipient!=. & Treatment_New==8, by(Treatment) //Control S2 vs LM2 S2
ranksum payoff_based_A_beliefs if payoff_recipient!=. & Treatment_New==7 | payoff_recipient!=. & Treatment_New==8, by(Treatment) //LM1 S2 vs LM2 S2

*************************************
***Analysis in Section 3.1:Study 1***
*************************************

drop if Session>3 //focusing on S1 and S2


***Extensive Margin: Chi Square Tests***


*Control vs LM1

ta Treatment_New selfish if payoff_recipient!=. & Treatment_New==0 | payoff_recipient!=. & Treatment_New==1, chi2 expected
ta Treatment_New smw_altruist if payoff_recipient!=. & Treatment_New==0 | payoff_recipient!=. & Treatment_New==1, chi2 expected
ta Treatment_New fair_and_above if payoff_recipient!=. & Treatment_New==0 | payoff_recipient!=. & Treatment_New==1, chi2 expected

*Control vs LM2

ta Treatment_New selfish if payoff_recipient!=. & Treatment_New==0 | payoff_recipient!=. & Treatment_New==2, chi2 expected
ta Treatment_New smw_altruist if payoff_recipient!=. & Treatment_New==0 | payoff_recipient!=. & Treatment_New==2, chi2 expected
ta Treatment_New fair_and_above if payoff_recipient!=. & Treatment_New==0 | payoff_recipient!=. & Treatment_New==2, chi2 expected

*LM1 vs LM2

ta Treatment_New selfish if payoff_recipient!=. & Treatment_New==1 | payoff_recipient!=. & Treatment_New==2, chi2 expected
ta Treatment_New smw_altruist if payoff_recipient!=. & Treatment_New==1 | payoff_recipient!=. & Treatment_New==2, chi2 expected
ta Treatment_New fair_and_above if payoff_recipient!=. & Treatment_New==1 | payoff_recipient!=. & Treatment_New==2, chi2 expected

***Intensive Margin: Mann-Whitney U Tests***

ranksum payoff_recipient if Treatment_New==0 | Treatment_New==1, by(Treatment_New) // Loss 1 vs Control
ranksum payoff_recipient if Treatment_New==0 | Treatment_New==2, by(Treatment_New) // Loss 2 vs Control
ranksum payoff_recipient if Treatment_New==1 | Treatment_New==2, by(Treatment_New) // Loss 1 vs Loss 2


**************************
***Section 3.2: Study 2***
**************************

***Extensive Margin: Chi Square Tests***

*Control vs LM1

ta Treatment_New selfish if payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==4, chi2 expected
ta Treatment_New smw_altruist if payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==4, chi2 expected
ta Treatment_New fair_and_above if payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==4, chi2 expected

*Control vs LM2

ta Treatment_New selfish if payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==5, chi2 expected
ta Treatment_New smw_altruist if payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==5, chi2 expected
ta Treatment_New fair_and_above if payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==5, chi2 expected

*LM1 vs LM2

ta Treatment_New selfish if payoff_recipient!=. & Treatment_New==4 | payoff_recipient!=. & Treatment_New==5, chi2 expected
ta Treatment_New smw_altruist if payoff_recipient!=. & Treatment_New==4 | payoff_recipient!=. & Treatment_New==5, chi2 expected
ta Treatment_New fair_and_above if payoff_recipient!=. & Treatment_New==4 | payoff_recipient!=. & Treatment_New==5, chi2 expected

***Intensive Margin: Mann-Whitney U Tests***

ranksum payoff_recipient if Treatment_New==3 | Treatment_New==4, by(Treatment_New) // Loss 1 vs Control
ranksum payoff_recipient if Treatment_New==3 | Treatment_New==5, by(Treatment_New) // Loss 2 vs Control
ranksum payoff_recipient if Treatment_New==4 | Treatment_New==5, by(Treatment_New) // Loss 1 vs Loss 2


******************
***APPENDIX A*****
******************


*Observable socio-demographic variables to be used in balancing tests

gen working=0
replace working=1 if employment==3 | employment==4

gen high_school_or_lower=0
replace high_school_or_lower=1 if education==1 | education==2 | education==3 

gen bachelor=0 
replace bachelor=1 if education==4

gen post_graduate=0
replace post_graduate=1 if education==5 | education==6 | education==7

gen conservative=0
replace conservative=1 if politics==1 | politics==2

gen liberal=0 
replace liberal=1 if politics==4 | politics==5

**********************************
***Tables A1-A4 balancing tests***
**********************************

*Study 1 Dictator

reg female i.Treatment_New if Treatment_New<3 & Player==1, robust
outreg using "tables/Table_balanceS1d", se bdec(3) ctitle("",Female) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A1: Balance Dictators)


reg age i.Treatment_New if Treatment_New<3  & Player==1, robust
outreg using "tables/Table_balanceS1d", se bdec(3) ctitle("",Age) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A1: Balance Dictators) ///
merge

reg working i.Treatment_New if Treatment_New<3 & Player==1, robust
outreg using "tables/Table_balanceS1d", se bdec(3) ctitle("",Working) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A1: Balance Dictators) ///
merge

reg high_school_or_lower i.Treatment_New if Treatment_New<3 & Player==1, robust
outreg using "tables/Table_balanceS1d", se bdec(3) ctitle("",School) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A1: Balance Dictators) ///
merge

reg bachelor i.Treatment_New if Treatment_New<3 & Player==1, robust
outreg using "tables/Table_balanceS1d", se bdec(3) ctitle("",Bachelor) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A1: Balance Dictators) ///
merge

reg post_graduate i.Treatment_New if Treatment_New<3 & Player==1, robust
outreg using "tables/Table_balanceS1d", se bdec(3) ctitle("",Post-Graduate) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A1: Balance Dictators) ///
merge

reg conservative i.Treatment_New if Treatment_New<3 & Player==1, robust
outreg using "tables/Table_balanceS1d", se bdec(3) ctitle("",Conservative) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A1: Balance Dictators) ///
merge

reg liberal i.Treatment_New if Treatment_New<3 & Player==1, robust
outreg using "tables/Table_balanceS1d", se bdec(3) ctitle("",Liberal) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A1: Balance Dictators) ///
merge


*Study 1 Recipient

reg female i.Treatment_New if Treatment_New<3 & Player==2, robust
outreg using "tables/Table_balanceS1r", se bdec(3) ctitle("",Female) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A2: Balance Recipients)


reg age i.Treatment_New if Treatment_New<3  & Player==2, robust
outreg using "tables/Table_balanceS1r", se bdec(3) ctitle("",Age) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A2: Balance Recipients) ///
merge

reg working i.Treatment_New if Treatment_New<3 & Player==2, robust
outreg using "tables/Table_balanceS1r", se bdec(3) ctitle("",Working) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A2: Balance Recipients) ///
merge

reg high_school_or_lower i.Treatment_New if Treatment_New<3 & Player==2, robust
outreg using "tables/Table_balanceS1r", se bdec(3) ctitle("",School) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A2: Balance Recipients) ///
merge

reg bachelor i.Treatment_New if Treatment_New<3 & Player==2, robust
outreg using "tables/Table_balanceS1r", se bdec(3) ctitle("",Bachelor) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A2: Balance Recipients) ///
merge

reg post_graduate i.Treatment_New if Treatment_New<3 & Player==2, robust
outreg using "tables/Table_balanceS1r", se bdec(3) ctitle("",Post-Graduate) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A2: Balance Recipients) ///
merge

reg conservative i.Treatment_New if Treatment_New<3 & Player==2, robust
outreg using "tables/Table_balanceS1r", se bdec(3) ctitle("",Conservative) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A2: Balance Recipients) ///
merge

reg liberal i.Treatment_New if Treatment_New<3 & Player==2, robust
outreg using "tables/Table_balanceS1r", se bdec(3) ctitle("",Liberal) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A2: Balance Recipients) ///
merge

*Study 2 Dictator

reg female i.Treatment_New if Treatment_New>=3 & Player==1, robust
outreg using "tables/Table_balanceS2d", se bdec(3) ctitle("",Female) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A3: Balance Dictators)

reg age i.Treatment_New if Treatment_New>=3 & Player==1, robust
outreg using "tables/Table_balanceS2d", se bdec(3) ctitle("",Age) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A3: Balance Dictators) ///
merge

reg working i.Treatment_New if Treatment_New>=3 & Player==1, robust
outreg using "tables/Table_balanceS2d", se bdec(3) ctitle("",Working) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A3: Balance Dictators) ///
merge

reg high_school_or_lower i.Treatment_New if Treatment_New>=3 & Player==1, robust
outreg using "tables/Table_balanceS2d", se bdec(3) ctitle("",School) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A3: Balance Dictators) ///
merge

reg bachelor i.Treatment_New if Treatment_New>=3 & Player==1, robust
outreg using "tables/Table_balanceS2d", se bdec(3) ctitle("",Bachelor) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A3: Balance Dictators) ///
merge

reg post_graduate i.Treatment_New if Treatment_New>=3 & Player==1, robust
outreg using "tables/Table_balanceS2d", se bdec(3) ctitle("",Post-Graduate) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A3: Balance Dictators) ///
merge

reg conservative i.Treatment_New if Treatment_New>=3 & Player==1, robust
outreg using "tables/Table_balanceS2d", se bdec(3) ctitle("",Conservative) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A3: Balance Dictators) ///
merge

reg liberal i.Treatment_New if Treatment_New>=3 & Player==1, robust
outreg using "tables/Table_balanceS2d", se bdec(3) ctitle("",Liberal) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A3: Balance Dictators) ///
merge

*Study 2 Recipient

reg female i.Treatment_New if Treatment_New>=3 & Player==2, robust
outreg using "tables/Table_balanceS2r", se bdec(3) ctitle("",Female) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A4: Balance Recipients)

reg age i.Treatment_New if Treatment_New>=3 & Player==2, robust
outreg using "tables/Table_balanceS2r", se bdec(3) ctitle("",Age) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A4: Balance Recipients) ///
merge

reg working i.Treatment_New if Treatment_New>=3 & Player==2, robust
outreg using "tables/Table_balanceS2r", se bdec(3) ctitle("",Working) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A4: Balance Recipients) ///
merge

reg high_school_or_lower i.Treatment_New if Treatment_New>=3 & Player==2, robust
outreg using "tables/Table_balanceS2r", se bdec(3) ctitle("",School) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A4: Balance Recipients) ///
merge

reg bachelor i.Treatment_New if Treatment_New>=3 & Player==2, robust
outreg using "tables/Table_balanceS2r", se bdec(3) ctitle("",Bachelor) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A4: Balance Recipients) ///
merge

reg post_graduate i.Treatment_New if Treatment_New>=3 & Player==2, robust
outreg using "tables/Table_balanceS2r", se bdec(3) ctitle("",Post-Graduate) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A4: Balance Recipients) ///
merge

reg conservative i.Treatment_New if Treatment_New>=3 & Player==2, robust
outreg using "tables/Table_balanceS2r", se bdec(3) ctitle("",Conservative) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A4: Balance Recipients) ///
merge

reg liberal i.Treatment_New if Treatment_New>=3 & Player==2, robust
outreg using "tables/Table_balanceS2r", se bdec(3) ctitle("",Liberal) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A4: Balance Recipients) ///
merge


*Table A7: Comparison of effort and windfall treatments in the extensive margin

ta Treatment_New selfish if payoff_recipient!=. & Treatment_New==0 | payoff_recipient!=. & Treatment_New==3, chi2 expected
ta Treatment_New selfish if payoff_recipient!=. & Treatment_New==1 | payoff_recipient!=. & Treatment_New==4, chi2 expected
ta Treatment_New selfish if payoff_recipient!=. & Treatment_New==2 | payoff_recipient!=. & Treatment_New==5, chi2 expected

ta Treatment_New fair_and_above if payoff_recipient!=. & Treatment_New==0 | payoff_recipient!=. & Treatment_New==3, chi2 expected
ta Treatment_New fair_and_above if payoff_recipient!=. & Treatment_New==1 | payoff_recipient!=. & Treatment_New==4, chi2 expected
ta Treatment_New fair_and_above if payoff_recipient!=. & Treatment_New==2 | payoff_recipient!=. & Treatment_New==5, chi2 expected


***Table A8: Comparison of effort and windfall treatments in the intensive margin

ranksum payoff_recipient if Treatment_New==0 | Treatment_New==3, by(Treatment_New) // Control S1 vs Control S2
ranksum payoff_recipient if Treatment_New==1 | Treatment_New==4, by(Treatment_New) // Loss 1 S1 vs Loss 1 S2
ranksum payoff_recipient if Treatment_New==2 | Treatment_New==5, by(Treatment_New) // Loss 2 S1 vs Loss 2 S2


****************
***Appendix B***
****************

*Table B1

reg selfish i.Treatment_New female working high_school bachelor post_graduate conservative liberal if payoff_recipient!=. & Treatment_New<3, robust

test 1.Treatment_New 2.Treatment_New

outreg using "tables/Table_regS1", se bdec(3) ctitle("",Selfish) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table B1. Study 1 results)

reg smw_altruist i.Treatment_New female working high_school bachelor post_graduate conservative liberal if payoff_recipient!=. & Treatment_New<3, robust

test 1.Treatment_New 2.Treatment_New

outreg using "tables/Table_regS1", se bdec(3) ctitle("", Somewhat altruistic) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table B1. Study 1 results) ///
merge

reg fair_and_above i.Treatment_New female working high_school bachelor post_graduate conservative liberal if payoff_recipient!=. & Treatment_New<3, robust

test 1.Treatment_New 2.Treatment_New

outreg using "tables/Table_regS1", se bdec(3) ctitle("",Highly altruistic) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table B1. Study 1 results) ///
merge

reg payoff_recipient i.Treatment_New female working high_school bachelor post_graduate conservative liberal if payoff_recipient!=. & Treatment_New<3, robust

test 1.Treatment_New 2.Treatment_New

outreg using "tables/Table_regS1", se bdec(3) ctitle("",Recipient's payoff) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table B1. Study 1 results) ///
merge


*Table B2

reg selfish i.Treatment_New female working high_school bachelor post_graduate conservative liberal if payoff_recipient!=. & Treatment_New>=3, robust

test 4.Treatment_New 5.Treatment_New

outreg using "tables/Table_regS2", se bdec(3) ctitle("",Selfish) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table B2. Study 2 results)

reg smw_altruist i.Treatment_New female working high_school bachelor post_graduate conservative liberal if payoff_recipient!=. & Treatment_New>=3, robust

test 4.Treatment_New 5.Treatment_New

outreg using "tables/Table_regS2", se bdec(3) ctitle("",Somewhat altruistic) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table B2. Study 2 results) ///
merge

reg fair_and_above i.Treatment_New female working high_school bachelor post_graduate conservative liberal if payoff_recipient!=. & Treatment_New>=3, robust

test 4.Treatment_New 5.Treatment_New

outreg using "tables/Table_regS2", se bdec(3) ctitle("",Entirely altruistic) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table B2. Study 2 results) ///
merge

reg payoff_recipient i.Treatment_New female working high_school bachelor post_graduate conservative liberal if payoff_recipient!=. & Treatment_New>=3, robust

test 4.Treatment_New 5.Treatment_New

outreg using "tables/Table_regS2", se bdec(3) ctitle("",Recipient's payoff) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitles(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table B2. Study 2 results) ///
merge


******************************************************************
***Sections 3.1 and 3.2: MULTIPLE HYPOTHESES TESTING CORRECTION***
******************************************************************

**To run the code for Table 3, deactivate Table 4, activate Table 3 (the 3 lines above), and run the code from the very beginning

*ssc install mhtexp

*Table 3
/*
	drop if Treatment_New>2
	mhtexp payoff_recipient selfish smw_altruist fair_and_above if payoff_recipient!=. & Treatment_New==0 | payoff_recipient!=. & Treatment_New==1 | payoff_recipient!=. & Treatment_New==2, ///
	treatment(Treatment_New) combo("pairwise")
*/
**To run the code for Table 3, deactivate Table 4, activate Table 3 (the 3 lines above), and run the code from the very beginning

*Table 4
/*
drop if Treatment_New<=2
gen Treatment_Newa=Treatment_New-3
drop if Treatment_Newa==.

mhtexp payoff_recipient selfish smw_altruist fair_and_above if payoff_recipient!=. & Treatment_Newa==0 | payoff_recipient!=. & Treatment_Newa==1 | payoff_recipient!=. & Treatment_Newa==2, ///
treatment(Treatment_Newa) combo("pairwise")
*/
*****END OF THIS FILE*****
