******************************************************************************************************************************************
****************ANALYSIS FOR THE PAPER "MIND THE FRAMING WHEN STUDYING SOCIAL PREFERENCES IN THE DOMAIN OF LOSSES"************************
******************************************************************************************************************************************

clear
use "data_loss_Final.dta" //choose your path

keep if Session==4 | Session==5 //foucsing on Study 3

***Participant Payoffs

gen payoff_recipient=.
replace payoff_recipient=A_decision if Treatment==0 & Player==2 //Player B's payoff in the control group
replace payoff_recipient=A_decision if Treatment==11 & Player==2 //Player B's payoff Loss manipulation 1
replace payoff_recipient=A_decision if Treatment==12 & Player==2 //Player B's Loss 1 Loss Manipulation 1 (No LOSS)

*3-A_decision=the amount of loss A sends to B. 3-(3-A_decision) is the payoff of the recipient. 

replace payoff_recipient=3-(3-A_decision) if Treatment==21 & Player==2 //Player B's payoff Loss manipulation 2
replace payoff_recipient=3 if Treatment==20 & Player==2 //Player B's payoff Loss manipulation 2 (NO LOSS)

***generating a new treatment variable

gen Treatment_New=.

replace Treatment_New=3 if RealEffort==1 & Treatment==0 //Control, Real Effort
replace Treatment_New=4 if RealEffort==1 & Treatment==11 //Loss 1, Real Effort
replace Treatment_New=5 if RealEffort==1 & Treatment==21 //Loss 2, Real Effort


label define treatment 3 "Control S3" 4 "LM1 S3"  5 "LM2 S3"
label values Treatment_New treatment



*Dictator types

gen selfish=0 if payoff_recipient!=.
replace selfish=1 if Treatment==0 & payoff_recipient==0 | Treatment==11 & payoff_recipient==0 | Treatment==21 & payoff_recipient==0 

gen smw_altruist=0 if payoff_recipient!=. 
replace smw_altruist=1 if Treatment==0 & payoff_recipient>0 & payoff_recipient<1.5 | Treatment==11 & payoff_recipient>0 & payoff_recipient<1.5 | ///
Treatment==21 & payoff_recipient>0 & payoff_recipient<1.5

gen fair_and_above=0 if payoff_recipient!=.
replace fair=1 if payoff_recipient!=. & Treatment==0 & payoff_recipient>=1.5 | payoff_recipient!=. & Treatment==11 & payoff_recipient>=1.5 | payoff_recipient!=. & Treatment==21 & payoff_recipient>=1.5 

*****************
***Section 3.2***
*****************

***Extensive Margin: Chi Square Tests***

*Control vs LM1

ta Treatment_New selfish if payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==4, chi2 expected
ta Treatment_New smw_altruist if payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==4, chi2 expected
ta Treatment_New fair_and_above if payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==4, chi2 expected

*Control vs LM2

ta Treatment_New selfish if payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==5, chi2 expected
ta Treatment_New smw_altruist if payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==5, chi2 expected
ta Treatment_New fair_and_above if payoff_recipient!=. & Treatment_New==3 | payoff_recipient!=. & Treatment_New==5, chi2 expected

*LM1 vs LM2

ta Treatment_New selfish if payoff_recipient!=. & Treatment_New==4 | payoff_recipient!=. & Treatment_New==5, chi2 expected
ta Treatment_New smw_altruist if payoff_recipient!=. & Treatment_New==4 | payoff_recipient!=. & Treatment_New==5, chi2 expected
ta Treatment_New fair_and_above if payoff_recipient!=. & Treatment_New==4 | payoff_recipient!=. & Treatment_New==5, chi2 expected

**Mann-Whitney U (intensive)

ranksum payoff_recipient if Treatment_New==3 | Treatment_New==4, by(Treatment_New) // Loss 1 vs Control E
ranksum payoff_recipient if Treatment_New==3 | Treatment_New==5, by(Treatment_New) // Loss 2 vs Control E
ranksum payoff_recipient if Treatment_New==4 | Treatment_New==5, by(Treatment_New) // Loss 1 vs Loss 2 E


*Loss perception: a chi-square test


ta LM1lossperception 
ta LM2lossperception

gen Loss_perception_combined=.

replace Loss_perception_combined=LM1lossperception if Player==1 & Treatment_New==4
replace Loss_perception_combined=LM2lossperception if Player==1 & Treatment_New==5

ta Treatment_New Loss_perception if Treatment_New==4 | Treatment_New==5, chi2 expected

**************
***Figure 4***
**************

cibar Loss_perception_combined if Player==1 & Treatment_New==4 | Player==1 & Treatment_New==5, over(Treatment_New) ///
bargap(10) barlabel(on) barcolor(mint teal) graphopts(ylabel(0(1)1, angle(0)) legend(size(small) position(6) rows(1)) graphregion(color(white)) ///
ytitle("Loss perception") text(1 1.25 "Study 3",place(e)))

graph save "figures/lossperception.gph", replace
graph export "figures/lossperception.png", replace

**************
***Figure 5***
**************

*Anger

cibar Emotion_1, over(Treatment_New) ///
bargap(10) barlabel(on) barcolor(dkgreen mint teal) graphopts(ylabel(0(1)7, angle(0)) legend(size(small) position(6) rows(1)) name(Anger, replace) graphregion(color(white)) ///
ytitle("Anger") text(7 1.85 "Anger",place(e)))

graph save "figures/Anger.gph", replace
graph export "figures/Anger.png", replace

*Surprise

cibar Emotion_2, over(Treatment_New) ///
bargap(10) barlabel(on) barcolor(dkgreen mint teal) graphopts(ylabel(0(1)7, angle(0)) legend(size(small) position(6) rows(1)) name(Surprise, replace) graphregion(color(white)) ///
ytitle("Surprise") text(7 1.85 "Surprise",place(e)))

graph save "figures/Surprise.gph", replace
graph export "figures/Surprise.png", replace


*Disappointment

cibar Emotion_3, over(Treatment_New) ///
bargap(10) barlabel(on) barcolor(dkgreen mint teal) graphopts(ylabel(0(1)7, angle(0)) legend(size(small) position(6) rows(1)) name(Disappointment, replace) graphregion(color(white)) ///
ytitle("Disappointment") text(7 1.85 "Disappointment",place(e)))

graph save "figures/Disappointment.gph", replace
graph export "figures/Disappointment.png", replace

*Joy

cibar Emotion_4, over(Treatment_New) ///
bargap(10) barlabel(on) barcolor(dkgreen mint teal) graphopts(ylabel(0(1)7, angle(0)) legend(size(small) position(6) rows(1)) name(Joy, replace) graphregion(color(white)) ///
ytitle("Joy") text(7 1.85 "Joy",place(e)))

graph save "figures/Joy.gph", replace
graph export "figures/Joy.png", replace

*Elation

cibar Emotion_5, over(Treatment_New) ///
bargap(10) barlabel(on) barcolor(dkgreen mint teal) graphopts(ylabel(0(1)7, angle(0)) legend(size(small) position(6) rows(1)) name(Elation, replace) graphregion(color(white)) ///
ytitle("Elation") text(7 1.85 "Elation",place(e)))

graph save "figures/Elation.gph", replace
graph export "figures/Elation.png", replace

*Jealousy

cibar Emotion_6, over(Treatment_New) ///
bargap(10) barlabel(on) barcolor(dkgreen mint teal) graphopts(ylabel(0(1)7, angle(0)) legend(size(small) position(6) rows(1)) name(Jealousy, replace) graphregion(color(white)) ///
ytitle("Jealousy") text(7 1.85 "Jealousy",place(e)))

graph save "figures/Jealousy.gph", replace
graph export "figures/Jealousy.png", replace


*Rage

cibar Emotion_7, over(Treatment_New) ///
bargap(10) barlabel(on) barcolor(dkgreen mint teal) graphopts(ylabel(0(1)7, angle(0)) legend(size(small) position(6) rows(1)) name(Rage, replace) graphregion(color(white)) ///
ytitle("Rage") text(7 1.85 "Rage",place(e)))

graph save "figures/Rage.gph", replace
graph export "figures/Rage.png", replace


*Frustration

cibar Emotion_8, over(Treatment_New) ///
bargap(10) barlabel(on) barcolor(dkgreen mint teal) graphopts(ylabel(0(1)7, angle(0)) legend(size(small) position(6) rows(1)) name(Frustration, replace) graphregion(color(white)) ///
ytitle("Frustration") text(7 1.85 "Frustration",place(e)))

graph save "figures/Frustration.gph", replace
graph export "figures/Frustration.png", replace


*Irritation

cibar Emotion_9, over(Treatment_New) ///
bargap(10) barlabel(on) barcolor(dkgreen mint teal) graphopts(ylabel(0(1)7, angle(0)) legend(size(small) position(6) rows(1)) name(Irritation, replace) graphregion(color(white)) ///
ytitle("Irritation") text(7 1.85 "Irritation",place(e)))

graph save "figures/Irritation.gph", replace
graph export "figures/Irritation.png", replace


*Sadness

cibar Emotion_10, over(Treatment_New) ///
bargap(10) barlabel(on) barcolor(dkgreen mint teal) graphopts(ylabel(0(1)7, angle(0)) legend(size(small) position(6) rows(1)) name(Sadness, replace) graphregion(color(white)) ///
ytitle("Sadness") text(7 1.85 "Sadness",place(e)))

graph save "figures/Sadness.gph", replace
graph export "figures/Sadness.png", replace

grc1leg Anger Surprise Disappointment Joy Elation Jealousy Rage Frustration Irritation Sadness

graph export "figures/combined_emotions.png", replace


*************
***Table 5***
*************

*Anger

ranksum Emotion_1 if Treatment_New==3 | Treatment_New==4, by(Treatment_New) // Loss 1 vs Control E
ranksum Emotion_1 if Treatment_New==3 | Treatment_New==5, by(Treatment_New) // Loss 2 vs Control E
ranksum Emotion_1 if Treatment_New==4 | Treatment_New==5, by(Treatment_New) // Loss 1 vs Loss 2 E


*Surprise

ranksum Emotion_2 if Treatment_New==3 | Treatment_New==4, by(Treatment_New) // Loss 1 vs Control E
ranksum Emotion_2 if Treatment_New==3 | Treatment_New==5, by(Treatment_New) // Loss 2 vs Control E
ranksum Emotion_2 if Treatment_New==4 | Treatment_New==5, by(Treatment_New) // Loss 1 vs Loss 2 E


*Disappointment

ranksum Emotion_3 if Treatment_New==3 | Treatment_New==4, by(Treatment_New) // Loss 1 vs Control E
ranksum Emotion_3 if Treatment_New==3 | Treatment_New==5, by(Treatment_New) // Loss 2 vs Control E
ranksum Emotion_3 if Treatment_New==4 | Treatment_New==5, by(Treatment_New) // Loss 1 vs Loss 2 E


*Joy

ranksum Emotion_4 if Treatment_New==3 | Treatment_New==4, by(Treatment_New) // Loss 1 vs Control E
ranksum Emotion_4 if Treatment_New==3 | Treatment_New==5, by(Treatment_New) // Loss 2 vs Control E
ranksum Emotion_4 if Treatment_New==4 | Treatment_New==5, by(Treatment_New) // Loss 1 vs Loss 2 E

*Elation

ranksum Emotion_5 if Treatment_New==3 | Treatment_New==4, by(Treatment_New) // Loss 1 vs Control E
ranksum Emotion_5 if Treatment_New==3 | Treatment_New==5, by(Treatment_New) // Loss 2 vs Control E
ranksum Emotion_5 if Treatment_New==4 | Treatment_New==5, by(Treatment_New) // Loss 1 vs Loss 2 E


*Jealousy

ranksum Emotion_6 if Treatment_New==3 | Treatment_New==4, by(Treatment_New) // Loss 1 vs Control E
ranksum Emotion_6 if Treatment_New==3 | Treatment_New==5, by(Treatment_New) // Loss 2 vs Control E
ranksum Emotion_6 if Treatment_New==4 | Treatment_New==5, by(Treatment_New) // Loss 1 vs Loss 2 E

*Rage

ranksum Emotion_7 if Treatment_New==3 | Treatment_New==4, by(Treatment_New) // Loss 1 vs Control E
ranksum Emotion_7 if Treatment_New==3 | Treatment_New==5, by(Treatment_New) // Loss 2 vs Control E
ranksum Emotion_7 if Treatment_New==4 | Treatment_New==5, by(Treatment_New) // Loss 1 vs Loss 2 E


*Frustration

ranksum Emotion_8 if Treatment_New==3 | Treatment_New==4, by(Treatment_New) // Loss 1 vs Control E
ranksum Emotion_8 if Treatment_New==3 | Treatment_New==5, by(Treatment_New) // Loss 2 vs Control E
ranksum Emotion_8 if Treatment_New==4 | Treatment_New==5, by(Treatment_New) // Loss 1 vs Loss 2 E


*Irritation

ranksum Emotion_9 if Treatment_New==3 | Treatment_New==4, by(Treatment_New) // Loss 1 vs Control E
ranksum Emotion_9 if Treatment_New==3 | Treatment_New==5, by(Treatment_New) // Loss 2 vs Control E
ranksum Emotion_9 if Treatment_New==4 | Treatment_New==5, by(Treatment_New) // Loss 1 vs Loss 2 E

*Saddness

ranksum Emotion_10 if Treatment_New==3 | Treatment_New==4, by(Treatment_New) // Loss 1 vs Control E
ranksum Emotion_10 if Treatment_New==3 | Treatment_New==5, by(Treatment_New) // Loss 2 vs Control E
ranksum Emotion_10 if Treatment_New==4 | Treatment_New==5, by(Treatment_New) // Loss 1 vs Loss 2 E


******************
***APPENDIX A*****
******************

*Tables A5,A6 balancing tests

*Observable socio-demographic variables to be used in balancing tests

gen working=0
replace working=1 if employment==3 | employment==4

gen high_school_or_lower=0
replace high_school_or_lower=1 if education==1 | education==2 | education==3 

gen bachelor=0 
replace bachelor=1 if education==4

gen post_graduate=0
replace post_graduate=1 if education==5 | education==6 | education==7

gen conservative=0
replace conservative=1 if politics==1 | politics==2

gen liberal=0 
replace liberal=1 if politics==4 | politics==5

**************
***Table A5***
**************

*Study 3 Dictator

reg female i.Treatment_New if Player==1, robust
outreg using "tables/Table_balanceS5d", se bdec(3) ctitle("",Female) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A5: Balance Dictators)


reg age i.Treatment_New if Player==1, robust
outreg using "tables/Table_balanceS5d", se bdec(3) ctitle("",Age) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A5: Balance Dictators) ///
merge

reg working i.Treatment_New if Player==1, robust
outreg using "tables/Table_balanceS5d", se bdec(3) ctitle("",Working) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A5: Balance Dictators) ///
merge

reg high_school_or_lower i.Treatment_New if Player==1, robust
outreg using "tables/Table_balanceS5d", se bdec(3) ctitle("",School) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A5: Balance Dictators) ///
merge

reg bachelor i.Treatment_New if Player==1, robust
outreg using "tables/Table_balanceS5d", se bdec(3) ctitle("",Bachelor) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A5: Balance Dictators) ///
merge

reg post_graduate i.Treatment_New if Player==1, robust
outreg using "tables/Table_balanceS5d", se bdec(3) ctitle("",Post-Graduate) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A5: Balance Dictators) ///
merge

reg conservative i.Treatment_New if Player==1, robust
outreg using "tables/Table_balanceS5d", se bdec(3) ctitle("",Conservative) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A5: Balance Dictators) ///
merge

reg liberal i.Treatment_New if Player==1, robust
outreg using "tables/Table_balanceS5d", se bdec(3) ctitle("",Liberal) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A5: Balance Dictators) ///
merge


*Table A6

reg female i.Treatment_New if Player==2, robust
outreg using "tables/Table_balanceS6r", se bdec(3) ctitle("",Female) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A6: Balance Recipients)


reg age i.Treatment_New if Player==2, robust
outreg using "tables/Table_balanceS6r", se bdec(3) ctitle("",Age) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A6: Balance Recipients) ///
merge

reg working i.Treatment_New if Player==2, robust
outreg using "tables/Table_balanceS6r", se bdec(3) ctitle("",Working) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A6: Balance Recipients) ///
merge

reg high_school_or_lower i.Treatment_New if Player==2, robust
outreg using "tables/Table_balanceS6r", se bdec(3) ctitle("",School) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A6: Balance Recipients) ///
merge

reg bachelor i.Treatment_New if Player==2, robust
outreg using "tables/Table_balanceS6r", se bdec(3) ctitle("",Bachelor) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A6: Balance Recipients) ///
merge

reg post_graduate i.Treatment_New if Player==2, robust
outreg using "tables/Table_balanceS6r", se bdec(3) ctitle("",Post-Graduate) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A6: Balance Recipients) ///
merge

reg conservative i.Treatment_New if Player==2, robust
outreg using "tables/Table_balanceS6r", se bdec(3) ctitle("",Conservative) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A6: Balance Recipients) ///
merge

reg liberal i.Treatment_New if Player==2, robust
outreg using "tables/Table_balanceS6r", se bdec(3) ctitle("",Liberal) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table A6: Balance Recipients) ///
merge

clear


**************************************
***Extracting qualitative responses***
**************************************

*clear
*use "data_loss_Final.dta" //choose your path

*keep if Player==1
*gen Response=""
*sort Treatment
*replace Response=JustificationsC if Treatment==0
*replace Response=JustificationsLM1 if Treatment==11 | Treatment==12
*replace Response=JustificationsLM2 if Treatment==20 | Treatment==21

*drop if Response==""
*drop if Treatment==20 | Treatment==12

*keep Treatment Player A_decision Response

*gen payoff_recipient=.
*replace payoff_recipient=A_decision if Treatment==0
*replace payoff_recipient=A_decision if Treatment==11
*replace payoff_recipient=3-(3-A_decision) if Treatment==21

*sort Treatment A_decision

*export excel using "Qualitative.xlsx", firstrow(variables) replace







